==> acquia_contenthub-8.x-2.3.tar.gz: acquia_contenthub/tests/fixtures/import/drupal-8.6/expectations/media/reference_2.php <==
<?php

/**
 * @file
 * Media file expectation.
 */

use Drupal\Tests\acquia_contenthub\Kernel\Stubs\CdfExpectations;

$expectations = [];
$data = [
  'uuid' => [
    'en' => [
      0 => [
        'value' => '3cd48a71-8215-4a46-806a-61fdb5cc05d5',
      ],
    ],
  ],
  'langcode' => [
    'en' => [
      0 => [
        'value' => 'en',
      ],
    ],
  ],
  'uid' => [
    'en' => [
      0 => [
        'target_id' => 'bda4cee4-da85-45ed-8a7f-92e8d3e797e7',
      ],
    ],
  ],
  'filename' => [
    'en' => [
      0 => [
        'value' => 'druplicon.png',
      ],
    ],
  ],
  'uri' => [
    'en' => [
      0 => [
        'value' => 'public://druplicon.png',
      ],
    ],
  ],
  'filemime' => [
    'en' => [
      0 => [
        'value' => 'image/png',
      ],
    ],
  ],
  'filesize' => [
    'en' => [
      0 => [
        'value' => '3905',
      ],
    ],
  ],
  'status' => [
    'en' => [
      0 => [
        'value' => '1',
      ],
    ],
  ],
  'created' => [
    'en' => [
      0 => [
        'value' => '1546527525',
      ],
    ],
  ],
  'changed' => [
    'en' => [
      0 => [
        'value' => '1546527535',
      ],
    ],
  ],
];

$expectations['3cd48a71-8215-4a46-806a-61fdb5cc05d5'] = new CdfExpectations($data, ['fid']);

$data = [
  'uuid' => [
    'en' => [
      0 =>
        [
          'value' => 'fcb8efaa-9431-4750-9703-b783b22a4a9f',
        ],
    ],
  ],
  'langcode' => [
    'en' => [
      0 =>
        [
          'value' => 'en',
        ],
    ],
  ],
  'uid' => [
    'en' => [
      0 =>
        [
          'target_id' => 'bda4cee4-da85-45ed-8a7f-92e8d3e797e7',
        ],
    ],
  ],
  'filename' => [
    'en' => [
      0 => [
        'value' => 'druplicon.png',
      ],
    ],
  ],
  'uri' => [
    'en' => [
      0 => [
        'value' => 'public://druplicon_0.png',
      ],
    ],
  ],
  'filemime' => [
    'en' => [
      0 => [
        'value' => 'image/png',
      ],
    ],
  ],
  'filesize' => [
    'en' => [
      0 => [
        'value' => '3905',
      ],
    ],
  ],
  'status' => [
    'en' => [
      0 => [
        'value' => '1',
      ],
    ],
  ],
  'created' => [
    'en' => [
      0 => [
        'value' => '1546527551',
      ],
    ],
  ],
  'changed' => [
    'en' => [
      0 => [
        'value' => '1546527553',
      ],
    ],
  ],
];

$expectations['fcb8efaa-9431-4750-9703-b783b22a4a9f'] = new CdfExpectations($data, ['fid']);

return $expectations;

==> acquia_contenthub-8.x-2.40.tar.gz: acquia_contenthub/tests/fixtures/import/drupal-9.4.15/expectations/media/reference_2.php <==
<?php

/**
 * @file
 * Media file expectation.
 */

use Drupal\Tests\acquia_contenthub\Kernel\Stubs\CdfExpectations;

$expectations = [];
$data = [
  'uuid' => [
    'en' => [
      0 => [
        'value' => '7e67c03a-24b1-4e38-892b-17405d1cbbd0',
      ],
    ],
  ],
  'langcode' => [
    'en' => [
      0 => [
        'value' => 'en',
      ],
    ],
  ],
  'uid' => [
    'en' => [
      0 => [
        'target_id' => 'c07e5269-91d0-4a1b-a31e-b0dcea8fcbaf',
      ],
    ],
  ],
  'filename' => [
    'en' => [
      0 => [
        'value' => 'druplicon.png',
      ],
    ],
  ],
  'uri' => [
    'en' => [
      0 => [
        'value' => 'public://2023-02/druplicon.png',
      ],
    ],
  ],
  'filemime' => [
    'en' => [
      0 => [
        'value' => 'image/png',
      ],
    ],
  ],
  'filesize' => [
    'en' => [
      0 => [
        'value' => '3905',
      ],
    ],
  ],
  'status' => [
    'en' => [
      0 => [
        'value' => '1',
      ],
    ],
  ],
  'created' => [
    'en' => [
      0 => [
        'value' => '1675432014',
      ],
    ],
  ],
  'changed' => [
    'en' => [
      0 => [
        'value' => '1675432135',
      ],
    ],
  ],
];

$expectations['7e67c03a-24b1-4e38-892b-17405d1cbbd0'] = new CdfExpectations($data, ['fid']);

$data = [
  'uuid' => [
    'en' => [
      0 =>
        [
          'value' => 'f35293d3-7ade-4514-852f-bcbca4aae158',
        ],
    ],
  ],
  'langcode' => [
    'en' => [
      0 =>
        [
          'value' => 'en',
        ],
    ],
  ],
  'uid' => [
    'en' => [
      0 =>
        [
          'target_id' => 'c07e5269-91d0-4a1b-a31e-b0dcea8fcbaf',
        ],
    ],
  ],
  'filename' => [
    'en' => [
      0 => [
        'value' => 'druplicon_0.png',
      ],
    ],
  ],
  'uri' => [
    'en' => [
      0 => [
        'value' => 'public://2023-02/druplicon_0.png',
      ],
    ],
  ],
  'filemime' => [
    'en' => [
      0 => [
        'value' => 'image/png',
      ],
    ],
  ],
  'filesize' => [
    'en' => [
      0 => [
        'value' => '3905',
      ],
    ],
  ],
  'status' => [
    'en' => [
      0 => [
        'value' => '1',
      ],
    ],
  ],
  'created' => [
    'en' => [
      0 => [
        'value' => '1675442931',
      ],
    ],
  ],
  'changed' => [
    'en' => [
      0 => [
        'value' => '1675442945',
      ],
    ],
  ],
];

$expectations['f35293d3-7ade-4514-852f-bcbca4aae158'] = new CdfExpectations($data, ['fid']);

return $expectations;
